dict_of_parts = {
    "4-ch-transceiver": "",
    "2xAA-battery-holder": "",
    "4xAA-battery-holder": "",
    "yellow-gearbox-dc-motor": "4 x 270 RPM",
    "yellow-wheels": "x 4",
    "L-1x2": "x 8",
    "M3": "🚧",
}
